# Contributing Guidelines for `spglm`

Thank you for your interest in contributing! We work primarily on Github. Please review the contributing procedures [here](http://pysal.org/getting_started#for-developers) and [here](https://github.com/pysal/pysal/wiki/GitHub-Standard-Operating-Procedures) so that we can accept your contributions! Alternatively, contact someone in the [development chat channel](https://gitter.im//pysal/pysal).


## Style and format

This project utilizes:
* [`black`](https://black.readthedocs.io/en/stable/) for formatting;
* [`ruff`](https://docs.astral.sh/ruff/) for linting; and
* [`pre-commit`](https://pre-commit.com) to check format and lint on commits prior to pull requests being made. 